
/* gcc -o vdev_libinput_wait vdev_libinput_wait.c `pkg-config --cflags --libs libinput libudev libevdev` -lvdev -lpstat */

#include "libvdev/sglib.h"
#include "libvdev/util.h"
#include "libvdev/misc.h"

#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>
#include <stdbool.h>
#include <sys/fcntl.h> 
#include <sys/ioctl.h>
#include <poll.h>

#include <libinput.h> 
#include <libudev.h>
#include <libevdev/libevdev.h>

typedef char* cstr;

// prototypes
SGLIB_DEFINE_VECTOR_PROTOTYPES (cstr);
SGLIB_DEFINE_VECTOR_FUNCTIONS (cstr);

static int open_restricted (const char *path, int flags, void *user_data)
{
	bool *grab = user_data;
	int fd = open(path, flags);

	if (fd < 0)
		fprintf(stderr, "Failed to open %s (%s)\n", path, strerror(errno));
	else if (grab && *grab && ioctl(fd, EVIOCGRAB, (void*)1) == -1)
		fprintf(stderr, "Grab requested, but failed for %s (%s)\n", path, strerror(errno));

	return fd < 0 ? -errno : fd;
}

static void close_restricted(int fd, void *user_data)
{
	close(fd);
}

static const struct libinput_interface interface = {
	.open_restricted = open_restricted,
	.close_restricted = close_restricted,
};

int main(int argc, char **argv)
{
    int rc = 0;	
	struct libinput *li = NULL;
	struct udev *udev = NULL;
	
    udev = udev_new();
	if (!udev) {
		fprintf(stderr, "Failed to initialize udev\n");
	    return EXIT_FAILURE;
	}

	li = libinput_udev_create_context(&interface, NULL, udev);
	if (!li) {
		fprintf(stderr, "Failed to initialize context from udev\n");
	    udev_unref (udev);
	    return EXIT_FAILURE;
	}
	
	if (libinput_udev_assign_seat(li, "seat0")) {
		fprintf(stderr, "Failed to set seat\n");
		libinput_unref(li);
	    udev_unref (udev);
	    return EXIT_FAILURE;
	}
	
    alarm(10);	
	
	while (1) {

		int rv;
		struct pollfd fd = {libinput_get_fd(li), POLLIN, 0};

		rv = poll (&fd, 1, 100);

		libinput_dispatch (li);

	    struct libinput_event *ev;
		
		while (ev = libinput_get_event(li)) {
			
		   if (libinput_event_get_type(ev) == LIBINPUT_EVENT_DEVICE_ADDED) {

	          struct libinput_device *dev = libinput_event_get_device(ev);
	          const char *name = libinput_device_get_name(dev);
	          
	          //if (strstr(name, " Touchpad"))
	             goto Out;
		
		   }
		}
	}
	
Out:
	
	libinput_unref(li);
	udev_unref (udev);

	return EXIT_SUCCESS;
}
